# Textual Timepiece

> Various time management related widgets for the [Textual](https://github.com/Textualize/textual) framework.

## Demo

Try the widgets out beforehand with `uv`:

```sh
uvx --from git+https://github.com/ddkasa/textual-timepiece demo
```

## Install

```sh
pip install textual-timepiece
```

```sh
uv add textual-timepiece
```

```sh
poetry add textual-timepiece
```

> [!NOTE]
> Requires [whenever](https://github.com/ariebovenberg/whenever) as an additional dependency.

## Included Widgets

- `DatePicker`
- `DurationPicker`
- `TimePicker`
- `DateTimePicker`
- `DateRangePicker`
- `DateTimeRangePicker`
- `ActivityHeatmap`
- `HeatmapManager`
- _And more to come..._

## License

MIT. Check [LICENSE](LICENSE.md) for more information.
